@@ -24,7 +24,7 @@ import os
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 from PyQt4 import uic
-from PyKDE4.kdeui import KIcon, KMessageBox
+from PyKDE4.kdeui import KIcon, KMessageBox, KGlobalSettings
 from PyKDE4.kdecore import KProcess, KStandardDirs, KUrl, i18n
 from PyKDE4.kio import KFileDialog
 
@@ -34,8 +34,11 @@ import gettext
 import logging
 
 from usbcreator.frontends.base import Frontend
-from usbcreator.misc import *
-from Queue import Queue
+from usbcreator import misc
+try:
+    from queue import Queue
+except ImportError:
+    from Queue import Queue
 
 queue = Queue()
 def thread_wrap(func):
@@ -86,7 +89,13 @@ class KdeFrontend(Frontend, QObject):
 
         #add any file sources passed
         if self.__img is not None:
-            self.__backend.add_image(unicode(self.__img))
+            self.__backend.add_image(misc.text_type(self.__img))
+
+        downloadsDir = QDir(KGlobalSettings.self().downloadPath())
+        isoFilter = []
+        isoFilter.append("*.iso")
+        for iso in downloadsDir.entryList(isoFilter, QDir.Files):
+            self.__backend.add_image(misc.text_type(downloadsDir.absoluteFilePath(iso)))
 
         def test_func(*a):
             if not queue.empty():
@@ -95,7 +104,7 @@ class KdeFrontend(Frontend, QObject):
                 queue.task_done()
             return True
         self.queue_processor = self.add_timeout(500, test_func, None)
-        
+
         self.__backend.detect_devices()
 
         self.update_loop = self.add_timeout(2000, self.__backend.update_free)
@@ -119,12 +128,12 @@ class KdeFrontend(Frontend, QObject):
         if 'USBCREATOR_LOCAL' in os.environ:
             appdir = os.path.join(os.getcwd(), 'gui')
         else:
-            file =  KStandardDirs.locate("appdata", self.__mainWindow_ui)
-            appdir = file.left(file.lastIndexOf("/"))
-        uic.loadUi(unicode(appdir + "/" + self.__mainWindow_ui), self.__mainWindow)
+            file = KStandardDirs.locate("appdata", self.__mainWindow_ui)
+            appdir = file[:file.rfind("/")]
+        uic.loadUi(misc.text_type(appdir + "/" + self.__mainWindow_ui), self.__mainWindow)
 
         #set default persist size
-        self.__mainWindow.ui_persist_label.setText(format_mb_size(128))
+        self.__mainWindow.ui_persist_label.setText(misc.format_mb_size(128))
 
         #set persistent ui elements state
         if self.__persistent:
@@ -157,7 +166,7 @@ class KdeFrontend(Frontend, QObject):
         self.connect(self.__mainWindow.ui_add_source,SIGNAL('clicked()'),
             self.add_file_source_dialog)
         self.connect(self.__mainWindow.ui_persist_slider,SIGNAL('valueChanged(int)'),
-            lambda value: self.__mainWindow.ui_persist_label.setText(format_mb_size(value)))
+            lambda value: self.__mainWindow.ui_persist_label.setText(misc.format_mb_size(value)))
         self.connect(self.__mainWindow.ui_quit_button,SIGNAL('clicked()'),
             self.quit)
         self.connect(self.__mainWindow.ui_start_button,SIGNAL('clicked()'),
@@ -210,7 +219,7 @@ class KdeFrontend(Frontend, QObject):
         sys.exit(1)
 
     def add_timeout(self, interval, func, *args):
-        '''Add a new timer for function 'func' with optional arguments. Mirrors a 
+        '''Add a new timer for function 'func' with optional arguments. Mirrors a
         similar gobject call timeout_add.'''
 
         # FIXME: now that we are part of a Qt object, we may be able to alter for builtin timers
@@ -231,12 +240,12 @@ class KdeFrontend(Frontend, QObject):
         return True
 
     def add_target(self, target):
-        logging.debug('add_target: %s' % unicode(target))
+        logging.debug('add_target: %s' % misc.text_type(target))
         new_item = QTreeWidgetItem(self.__mainWindow.ui_dest_list)
         new_item.setData(0,Qt.UserRole,target)
         # FIXME:
         # the new_item lines should be auto triggered onChange to the
-        # TreeWidget when new_item is appended. 
+        # TreeWidget when new_item is appended.
         new_item.setText(0,target)
         new_item.setIcon(0,KIcon("drive-removable-media-usb-pendrive"))
 
@@ -252,17 +261,17 @@ class KdeFrontend(Frontend, QObject):
             pretty_name = "%s %s (%s)" % (dev['vendor'], dev['model'], dev['device'])
             new_item.setText(0,pretty_name)
             new_item.setText(1,dev['label'])
-            new_item.setText(2,format_size(dev['capacity']))
+            new_item.setText(2,misc.format_size(dev['capacity']))
             free = dev['free']
             if free >= 0:
-                new_item.setText(3,format_size(free))
+                new_item.setText(3,misc.format_size(free))
             else:
                 new_item.setText(3,'')
- 
+
     def remove_target(self, target):
         for i in range(0,self.__mainWindow.ui_dest_list.topLevelItemCount()):
             item = self.__mainWindow.ui_dest_list.topLevelItem(i)
-            if item.data(0,Qt.UserRole).toPyObject() == target:
+            if item.data(0,Qt.UserRole) == target:
                 self.__mainWindow.ui_dest_list.takeTopLevelItem(i)
                 break
 
@@ -272,7 +281,7 @@ class KdeFrontend(Frontend, QObject):
                 self.__mainWindow.ui_dest_list.setCurrentItem(item,True)
 
     def add_source(self, source):
-        logging.debug('add_source: %s' % unicode(source))
+        logging.debug('add_source: %s' % misc.text_type(source))
         new_item = QTreeWidgetItem(self.__mainWindow.ui_source_list)
         new_item.setData(0,Qt.UserRole,source)
         # FIXME:
@@ -291,13 +300,14 @@ class KdeFrontend(Frontend, QObject):
         # populate from device data
         if self.__backend is not None:
             new_item.setText(0,self.__backend.sources[source]['device'])
-            new_item.setText(1,self.__backend.sources[source]['label'])
-            new_item.setText(2,format_size(self.__backend.sources[source]['size']))
- 
+            # Strip as some derivates like to have whitespaces/newlines (e.g. netrunner)
+            new_item.setText(1,self.__backend.sources[source]['label'].strip())
+            new_item.setText(2,misc.format_size(self.__backend.sources[source]['size']))
+
     def remove_source(self, source):
         for i in range(0,self.__mainWindow.ui_source_list.topLevelItemCount()):
             item = self.__mainWindow.ui_source_list.topLevelItem(i)
-            if item.data(0,Qt.UserRole).toPyObject() == source:
+            if item.data(0,Qt.UserRole) == source:
                 self.__mainWindow.ui_source_list.removeItemWidget(item,0)
                 break
 
@@ -311,7 +321,7 @@ class KdeFrontend(Frontend, QObject):
         item = self.__mainWindow.ui_source_list.currentItem()
         if item:
             # Must deal in unicode and not QString for backend
-            source = unicode(item.data(0,Qt.UserRole).toPyObject())
+            source = misc.text_type(item.data(0,Qt.UserRole))
             return source
         else:
             logging.debug('No source selected.')
@@ -322,7 +332,7 @@ class KdeFrontend(Frontend, QObject):
         item = self.__mainWindow.ui_dest_list.currentItem()
         if item:
             # Must deal in unicode and not QString for backend
-            dest = unicode(item.data(0,Qt.UserRole).toPyObject())
+            dest = misc.text_type(item.data(0,Qt.UserRole))
             return dest
         else:
             logging.debug('No target selected.')
@@ -339,7 +349,7 @@ class KdeFrontend(Frontend, QObject):
     def update_target(self, udi):
         for i in range(0,self.__mainWindow.ui_dest_list.topLevelItemCount()):
             item = self.__mainWindow.ui_dest_list.topLevelItem(i)
-            if unicode(item.data(0,Qt.UserRole).toPyObject()) == udi:
+            if misc.text_type(item.data(0,Qt.UserRole)) == udi:
                 self.__mainWindow.ui_dest_list.emit(
                     SIGNAL('itemChanged(item,0)'))
                 break
@@ -348,28 +358,29 @@ class KdeFrontend(Frontend, QObject):
         self.__mainWindow.ui_start_button.setEnabled(False)
         target = self.__backend.targets[udi]
         persist_mb = target['persist'] / 1024 / 1024
-        if persist_mb > MIN_PERSISTENCE:
+        if persist_mb > misc.MIN_PERSISTENCE:
             self.__mainWindow.ui_persist_frame.setEnabled(True)
-            self.__mainWindow.ui_persist_slider.setRange(MIN_PERSISTENCE, persist_mb)
+            self.__mainWindow.ui_persist_slider.setRange(
+                misc.MIN_PERSISTENCE, persist_mb)
         # Update install button state.
         status = target['status']
         source = self.__backend.get_current_source()
         if not source:
             return
         stype = self.__backend.sources[source]['type']
-        if (status == CAN_USE or 
-         (self.__mainWindow.ui_start_button.isEnabled() and stype == SOURCE_IMG)):
+        if (status == misc.CAN_USE or
+         (self.__mainWindow.ui_start_button.isEnabled() and stype == misc.SOURCE_IMG)):
             self.__mainWindow.ui_start_button.setEnabled(True)
         else:
             self.__mainWindow.ui_start_button.setEnabled(False)
-            status = NEED_FORMAT
+            status = misc.NEED_FORMAT
         # Update the destination status message.
-        if status == CANNOT_USE:
+        if status == misc.CANNOT_USE:
             msg = _('The device is not large enough to hold this image.')
-        elif status == NEED_SPACE:
+        elif status == misc.NEED_SPACE:
             msg = _('There is not enough free space for this image.')
             # FIXME RBG: 04/01/10 - Need Open button for folder to device for removing files
-        elif status == NEED_FORMAT:
+        elif status == misc.NEED_FORMAT:
             msg = _('The device needs to be formatted for use.')
         else:
             msg = ''
@@ -380,7 +391,7 @@ class KdeFrontend(Frontend, QObject):
         if not self.__backend:
             return
         if current_item is not None:
-            udi = unicode(current_item.data(0,Qt.UserRole).toPyObject())
+            udi = misc.text_type(current_item.data(0,Qt.UserRole))
         else:
             udi = None
         self.__backend.set_current_source(udi)
@@ -398,16 +409,16 @@ class KdeFrontend(Frontend, QObject):
         if current_item is None:
             return
 
-        udi = unicode(current_item.data(0,Qt.UserRole).toPyObject())
+        udi = misc.text_type(current_item.data(0,Qt.UserRole))
         self.update_target(udi)
 
     def add_file_source_dialog(self):
         filename = ''
-        filter = QString('*.iso|' + _('CD Images') + '\n*.img|' + _('Disk Images'))
+        filter = '*.iso|' + _('CD Images') + '\n*.img|' + _('Disk Images')
         # FIXME: should set the default path KUrl to users home dir...
         # This is all screwy as its run as root under kdesudo... Home = root and not user.. blarg!
         # Need to convert to plain string for backend to work
-        filename = unicode(KFileDialog.getOpenFileName(KUrl(),filter))
+        filename = misc.text_type(KFileDialog.getOpenFileName(KUrl(),filter))
         if not filename:
           return
         self.__backend.add_image(filename)
@@ -436,7 +447,7 @@ class KdeFrontend(Frontend, QObject):
         # Updating value cause dialog to re-appear from hidden (dunno why)
         if not self.progress_bar.isHidden():
             self.progress_bar.setValue(int(complete))
-    
+
     @thread_wrap
     def progress_message(self, message):
         self.progress_bar.setLabelText(message)
@@ -493,13 +504,11 @@ class KdeFrontend(Frontend, QObject):
         self.progress_bar.show()
 
     def format_ended(self):
-        self.__backend.formatting = None
         self.__mainWindow.unsetCursor()
         self.__mainWindow.ui_format_dest.setEnabled(True)
 
     @thread_wrap
     def format_failed(self, message):
-        self.__backend.formatting = None
         self.__mainWindow.unsetCursor()
         self.__mainWindow.ui_format_dest.setEnabled(True)
         # TODO sort through error types (message.get_dbus_name()) in backend,
@@ -510,7 +519,7 @@ class KdeFrontend(Frontend, QObject):
         item = self.__mainWindow.ui_dest_list.currentItem()
         if not item:
             return
-        udi = unicode(item.data(0,Qt.UserRole).toPyObject())
+        udi = misc.text_type(item.data(0,Qt.UserRole))
 
         text = _('Are you sure you want to erase the entire disk?')
 
